@@ -9,10 +9,10 @@ async fn main()->Result<()> {
     let (left,right)=pipe();
 
     let join:JoinHandle<Result<()>>= tokio::spawn(async move{
-        for i in 0..1000000 {
+        for i in 0..100000 {
             right.send(i);
             let ok=right.recv().await?;
-            ensure!(ok==i+1,"left return v error!!")
+            ensure!(ok==i+1,"left return v error!!");
         }
         Ok(())
     });
@@ -25,7 +25,7 @@ async fn main()->Result<()> {
             break;
         }
     }
-    println!("time {}ms",start.elapsed().as_millis());
+    println!("time {}ms",start.elapsed().as_secs_f32());
 
     join.await??;
 
