@@ -10,7 +10,7 @@ async fn main()->Result<()> {
 
     let res:Result<()>= single_runtime.run_until(async move{
         let join:JoinHandle<Result<()>>= tokio::task::spawn_local(async move{
-            for i in 0..1000000 {
+            for i in 0..100000 {
                 right.send(i);
                 let ok=right.recv().await?;
                 ensure!(ok==i+1,"left return v error!!")
@@ -26,7 +26,7 @@ async fn main()->Result<()> {
                 break;
             }
         }
-        println!("time {}ms",start.elapsed().as_millis());
+        println!("time {}ms",start.elapsed().as_secs_f32());
 
         join.await??;
         Ok(())
